==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnMoveOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnMoveOptionsDescription } from "./GridColumnMoveOptionsDescription";
/**
 * @hidden
 */
export let GridColumnMoveOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnMoveOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnMoveOptionsDescriptionMetadata.a == null) {
                GridColumnMoveOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnMoveOptionsDescriptionMetadata.c(GridColumnMoveOptionsDescriptionMetadata.a);
            }
            if (a.j(GridColumnMoveOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnMoveOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("MoveLeftCaption", "String");
            a.item("MoveRightCaption", "String");
        }
        static d(a) {
            GridColumnMoveOptionsDescriptionMetadata.b(a);
            a.aa("GridColumnMoveOptions", () => new GridColumnMoveOptionsDescription());
            a.z("GridColumnMoveOptions", GridColumnMoveOptionsDescriptionMetadata.a);
        }
    }
    GridColumnMoveOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnMoveOptionsDescriptionMetadata, 'GridColumnMoveOptionsDescriptionMetadata');
    GridColumnMoveOptionsDescriptionMetadata.a = null;
    return GridColumnMoveOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnMoveOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnMoveOptionsDescription } from "./GridColumnMoveOptionsDescription";
/**
 * @hidden
 */
export let GridColumnMoveOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnMoveOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnMoveOptionsDescriptionMetadata.a == null) {
                GridColumnMoveOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnMoveOptionsDescriptionMetadata.c(GridColumnMoveOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnMoveOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnMoveOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("MoveLeftCaption", "String");
            a.item("MoveRightCaption", "String");
        }
        static d(a) {
            GridColumnMoveOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnMoveOptions", () => new GridColumnMoveOptionsDescription());
            a.ab("GridColumnMoveOptions", GridColumnMoveOptionsDescriptionMetadata.a);
        }
    }
    GridColumnMoveOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnMoveOptionsDescriptionMetadata, 'GridColumnMoveOptionsDescriptionMetadata');
    GridColumnMoveOptionsDescriptionMetadata.a = null;
    return GridColumnMoveOptionsDescriptionMetadata;
})();
